# AUTOGENERATED! DO NOT EDIT! File to edit: 00_beproductive.ipynb (unless otherwise specified).

__all__ = ['main', 'parse_arguments']

# Cell
from .blocker import *
from .pomodoro import *
import argparse

# Cell
def main(action):
    print(f"Main! {action}")

# Cell
def parse_arguments():
    parser = argparse.ArgumentParser(description="Block addictive websites. Study with the Pomodoro technique.")
    parser.add_argument('action', help='block or unblock websites, or start a Pomodoro session', \
                        nargs='?', choices=['block', 'unblock', 'pomodoro'])
    args = parser.parse_args()
    print(args)
    return args

# Cell
if __name__ == '__main__':
    args = parse_arguments()
    main(args.action)