# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"main": "00_beproductive.ipynb",
         "parse_arguments": "00_beproductive.ipynb",
         "in_notebook": "00_beproductive.ipynb",
         "APP_NAME": "01_blocker.ipynb",
         "REDIRECT": "01_blocker.ipynb",
         "WIN_PATH": "01_blocker.ipynb",
         "LINUX_PATH": "01_blocker.ipynb",
         "ICON_PATH": "01_blocker.ipynb",
         "BLOCKLIST": "01_blocker.ipynb",
         "host_fp": "01_blocker.ipynb",
         "host_fp_copy": "01_blocker.ipynb",
         "host_fp_blocked": "01_blocker.ipynb",
         "Blocker": "01_blocker.ipynb",
         "WORK_TIME": "02_pomodoro.ipynb",
         "BREAK_TIME": "02_pomodoro.ipynb",
         "POMODOROS": "02_pomodoro.ipynb",
         "pomodoro": "02_pomodoro.ipynb"}

modules = ["__main__.py",
           "blocker.py",
           "pomodoro.py"]

doc_url = "https://johannesstutz.github.io/beproductive/"

git_url = "https://github.com/johannesstutz/beproductive/tree/master/"

def custom_doc_links(name): return None
